@@ -164,6 +164,42 @@ def test_aqua_photon_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_debian_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2019-18625.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_aqua_debian2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2023-21500.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_aqua_debian3_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3567.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_aqua_debian4_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "DLA-981-1.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 def test_convert(test_cve_json):
     nvdlatest = NvdSource()
     data = nvdlatest.convert(test_cve_json)
@@ -277,6 +313,10 @@ def test_aqua_convert(
     test_aqua_opensuse_json,
     test_aqua_suse_json,
     test_aqua_photon_json,
+    test_aqua_debian_json,
+    test_aqua_debian2_json,
+    test_aqua_debian3_json,
+    test_aqua_debian4_json,
 ):
     aqualatest = AquaSource()
     cve_data = aqualatest.convert(test_aqua_alsa_json)
@@ -303,3 +343,11 @@ def test_aqua_convert(
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_photon_json)
     assert cve_data
+    cve_data = aqualatest.convert(test_aqua_debian_json)
+    assert cve_data
+    cve_data = aqualatest.convert(test_aqua_debian2_json)
+    assert not cve_data
+    cve_data = aqualatest.convert(test_aqua_debian3_json)
+    assert cve_data
+    cve_data = aqualatest.convert(test_aqua_debian4_json)
+    assert cve_data
