@@ -33,8 +33,10 @@ except ImportError:
 json_lib = orjson if ORJSON_AVAILABLE else json
 
 threat_to_severity = {
+    "": "LOW",
     "negligible": "LOW",
     "low": "LOW",
+    "unimportant": "LOW",
     "severity_low": "LOW",
     "medium": "MEDIUM",
     "severity_medium": "MEDIUM",
@@ -107,13 +109,14 @@ class AquaSource(NvdSource):
             return self.suse_to_vuln(cve_data)
         elif cve_data.get("os_version"):
             return self.photon_to_vuln(cve_data)
+        elif cve_data.get("Annotations") and cve_data.get("Header"):
+            return self.debian_to_vuln(cve_data)
         return []
 
     def is_supported_source(self, zfname):
         for distro in (
             "alpine",
             "cwe",
-            "debian",
             "ghsa",
             "go",
             "nvd",
@@ -694,3 +697,98 @@ class AquaSource(NvdSource):
             except Exception as e:
                 pass
         return ret_data
+
+    def debian_to_vuln(self, cve_data):
+        """Debian Linux"""
+        ret_data = []
+        header = cve_data.get("Header")
+        annotations = cve_data.get("Annotations")
+        cve_id = header.get("ID")
+        pkg_name = ""
+        cwe_id = ""
+        references = []
+        description = header.get("Description", "").replace("(", "").replace(")", "")
+        assigner = "debian"
+        vendor = "debian"
+        for ann in annotations:
+            if ann.get("Type") == "RESERVED" or ann.get("Original") == "RESERVED":
+                continue
+            # Try to dealias
+            if (
+                not cve_id.startswith("CVE")
+                and ann.get("Type") == "xref"
+                and ann.get("Bugs")
+            ):
+                aliases_block = """
+## Related CVE(s)
+{}
+            """.format(
+                    ", ".join(ann.get("Bugs"))
+                )
+                description += aliases_block
+                for bug in ann.get("Bugs"):
+                    if bug.startswith("CVE"):
+                        cve_id = bug
+                        break
+            kind = ann.get("Kind")
+            if kind not in ("fixed", "unfixed", "no-dsa"):
+                continue
+            pkg_name = ann.get("Package")
+            if not pkg_name:
+                continue
+            distro_name = ann.get("Release")
+            if distro_name:
+                pkg_name = f"{distro_name}/{pkg_name}"
+            version = ann.get("Version", "99.99.9")
+            # Remove epoch
+            if ":" in version:
+                version = version.split(":")[-1]
+            severity = "MEDIUM"
+            if ann.get("Severity"):
+                severity = threat_to_severity.get(ann.get("Severity"), "MEDIUM")
+            score, severity, vectorString, attackComplexity = get_default_cve_data(
+                severity
+            )
+            publishedDate = ""
+            lastModifiedDate = ""
+            version_start_including = ""
+            version_end_including = ""
+            version_start_excluding = ""
+            version_end_excluding = version
+            fix_version_end_including = ""
+            fix_version_start_excluding = ""
+            fix_version_end_excluding = ""
+            fix_version_start_including = version
+            if pkg_name and version_end_excluding:
+                tdata = config.CVE_TPL % dict(
+                    cve_id=cve_id,
+                    cwe_id=cwe_id,
+                    assigner=assigner,
+                    references=references,
+                    description="",
+                    vectorString=vectorString,
+                    vendor=vendor,
+                    product=pkg_name,
+                    version="*",
+                    version_start_including=version_start_including,
+                    version_end_including=version_end_including,
+                    version_start_excluding=version_start_excluding,
+                    version_end_excluding=version_end_excluding,
+                    fix_version_start_including=fix_version_start_including,
+                    fix_version_end_including=fix_version_end_including,
+                    fix_version_start_excluding=fix_version_start_excluding,
+                    fix_version_end_excluding=fix_version_end_excluding,
+                    severity=severity,
+                    attackComplexity=attackComplexity,
+                    score=score,
+                    exploitabilityScore=score,
+                    publishedDate=publishedDate,
+                    lastModifiedDate=lastModifiedDate,
+                )
+                try:
+                    vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
+                    vuln.description = description
+                    ret_data.append(vuln)
+                except Exception as e:
+                    pass
+        return ret_data
