@@ -181,6 +181,7 @@ class OSVSource(NvdSource):
             ranges = pkg_data.get("ranges", [])
             vendor = pkg_data.get("package", {}).get("ecosystem", "").lower()
             pkg_name = pkg_data.get("package", {}).get("name", "")
+            pkg_name_list = []
             purl = parse_purl(pkg_data.get("package", {}).get("purl", ""))
             if purl:
                 if purl.get("namespace"):
@@ -192,10 +193,17 @@ class OSVSource(NvdSource):
                 if len(tmpA) == 2:
                     vendor = tmpA[0]
                     pkg_name = tmpA[-1]
-            # For OS packages, such as alpine OSV appends the os version to the vendor which is weird
-            # Let's remove it to keep things sane
-            if ":" in vendor:
-                vendor = vendor.split(":")[0]
+            pkg_name_list.append(pkg_name)
+            # For OS packages, such as alpine OSV appends the os version to the vendor
+            # Let's remove it and add it to package name
+            if ":" in vendor and ("alpine" in vendor or "debian" in vendor):
+                tmpV = vendor.split(":")
+                vendor = tmpV[0].lower()
+                # Only use the precise version for debian
+                if "debian" in vendor:
+                    pkg_name_list = [f"{vendor}-{tmpV[1]}/{pkg_name}"]
+                else:
+                    pkg_name_list.append(f"{vendor}-{tmpV[1]}/{pkg_name}")
             # Substitute alpine for apk and debian for deb
             if vendor_overrides.get(vendor):
                 vendor = vendor_overrides.get(vendor)
@@ -227,50 +235,51 @@ class OSVSource(NvdSource):
                         fix_version_end_including = ""
                         fix_version_start_excluding = ""
                         fix_version_end_excluding = ""
-                        version_start_including = ev.get("introduced")
+                        version_start_including = ev.get("introduced").split(":")[-1]
                     if ev.get("fixed"):
-                        fix_version_start_including = ev.get("fixed")
-                        fix_version_end_including = ev.get("fixed")
-                        version_end_excluding = ev.get("fixed")
+                        fix_version_start_including = ev.get("fixed").split(":")[-1]
+                        fix_version_end_including = ev.get("fixed").split(":")[-1]
+                        version_end_excluding = ev.get("fixed").split(":")[-1]
                     if ev.get("last_affected"):
-                        version_end_including = ev.get("last_affected")
+                        version_end_including = ev.get("last_affected").split(":")[-1]
                     if ev.get("limit"):
-                        version_end_excluding = ev.get("limit")
+                        version_end_excluding = ev.get("limit").split(":")[-1]
                     # Create an entry for each introduced + fixed/limit event
                     if version_start_including and (
                         fix_version_start_including
                         or version_end_including
                         or version_end_excluding
                     ):
-                        tdata = config.CVE_TPL % dict(
-                            cve_id=cve_id,
-                            cwe_id=cwe_id,
-                            assigner=assigner,
-                            references=references,
-                            description="",
-                            vectorString=vectorString,
-                            vendor=vendor,
-                            product=pkg_name,
-                            version="*",
-                            version_start_including=version_start_including,
-                            version_end_including=version_end_including,
-                            version_start_excluding=version_start_excluding,
-                            version_end_excluding=version_end_excluding,
-                            fix_version_start_including=fix_version_start_including,
-                            fix_version_end_including=fix_version_end_including,
-                            fix_version_start_excluding=fix_version_start_excluding,
-                            fix_version_end_excluding=fix_version_end_excluding,
-                            severity=severity,
-                            attackComplexity=attackComplexity,
-                            score=score,
-                            exploitabilityScore=exploitabilityScore,
-                            publishedDate=cve_data.get("published"),
-                            lastModifiedDate=cve_data.get("modified"),
-                        )
-                        try:
-                            vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
-                            vuln.description = description
-                            ret_data.append(vuln)
-                        except Exception as e:
-                            pass
+                        for full_pkg in pkg_name_list:
+                            tdata = config.CVE_TPL % dict(
+                                cve_id=cve_id,
+                                cwe_id=cwe_id,
+                                assigner=assigner,
+                                references=references,
+                                description="",
+                                vectorString=vectorString,
+                                vendor=vendor,
+                                product=full_pkg,
+                                version="*",
+                                version_start_including=version_start_including,
+                                version_end_including=version_end_including,
+                                version_start_excluding=version_start_excluding,
+                                version_end_excluding=version_end_excluding,
+                                fix_version_start_including=fix_version_start_including,
+                                fix_version_end_including=fix_version_end_including,
+                                fix_version_start_excluding=fix_version_start_excluding,
+                                fix_version_end_excluding=fix_version_end_excluding,
+                                severity=severity,
+                                attackComplexity=attackComplexity,
+                                score=score,
+                                exploitabilityScore=exploitabilityScore,
+                                publishedDate=cve_data.get("published"),
+                                lastModifiedDate=cve_data.get("modified"),
+                            )
+                            try:
+                                vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
+                                vuln.description = description
+                                ret_data.append(vuln)
+                            except Exception as e:
+                                pass
         return ret_data
